@@ -707,7 +707,7 @@ def sequence_repeater(context, render_kwargs, name=None, with_adder=False, with_
     context.write('</div>')
     context.write(tag('input', type='hidden', name='__end__', value=value, _closed=closed))
     if with_adder:
-        adder_css_class = to_css_class(_determine_css_classes(render_kwargs, 'adder'))
+        adder_css_class = _to_css_class(_determine_css_classes(render_kwargs, 'adder'))
         context.write(tag('input', type_='button', class_=adder_css_class, _closed=closed, value='Add'))
     if hasattr(context['caller'], 'footer'):
         context['caller'].footer()
